in_app_logview library
Classes
- FloatingLogButton
- A floating button that appears in debug mode to open the log viewer.
- FlutterLogsIntegration
-
Integration helper for the
flutter_logspackage. - InAppLog
- Main class for managing the in-app log viewer.
- InAppLogDioInterceptor
- Dio interceptor for logging API requests and responses to in_app_logview.
- InAppLogOutput
-
Integration helper for the
loggerpackage. - LogCapture
- Manages the capture and streaming of log entries.
- LogEntry
- Represents a single log entry with timestamp, message, level, and optional tag.
- LogFilter
- An abstract filter of log messages.
- Logger
- Use instances of logger to send log messages to the LogPrinter.
- LoggerIntegration
- Helper class for logger package integration.
- LogOutput
-
Log output receives a
OutputEventfrom LogPrinter and sends it to the desired destination. - LogPrinter
- An abstract handler of log events.
- LogViewer
- The main log viewer widget that displays logs in a console-like interface.
- LogViewOverlay
- Manages the overlay that displays the log viewer.
- LogViewWrapper
- A widget that wraps your app and provides the floating log button.
- PrettyPrinter
- Default implementation of LogPrinter.
- SimplePrinter
- Outputs simple log messages:
Enums
- FloatingButtonPosition
- Enum for floating button positions.
- Level
- Levels to control logging output. Logging can be enabled to include all levels above certain Level.
- LogLevel
- Enum representing different log levels.